package com.djhk.uav.equ.service;


import com.djhk.common.api.domain.vo.FileVo;
import com.djhk.common.exception.ServiceException;
import com.djhk.uav.equ.domain.EquModel;
import com.djhk.uav.equ.domain.vo.EquModelExportVo;
import org.springframework.web.multipart.MultipartFile;

import java.util.List;
import java.util.Map;

/**
 * 设备型号Service接口
 *
 * @author huangqg
 * @date 2023-06-01
 */
public interface IEquModelService
{
    /**
     * 查询设备型号
     *
     * @param modelId 设备型号主键
     * @return 设备型号
     */
    public EquModel selectEquModelByModelId(Long modelId);

    /**
     * 查询设备型号列表
     *
     * @param equModel 设备型号
     * @return 设备型号集合
     */
    public List<EquModel> selectEquModelList(EquModel equModel);

    FileVo uploadFile(MultipartFile file);

    /**
     * 新增设备型号
     *
     * @param equModel 设备型号
     * @return 结果
     */
    public int insertEquModel(EquModel equModel);

    /**
     * 查询设备型号编码
     *
     * @param modeCode 型号编码
     * @return 结果
     */
    List<EquModel> checkModelCode(String modeCode);

    /**
     * 修改设备型号
     *
     * @param equModel 设备型号
     * @return 结果
     */
    public int updateEquModel(EquModel equModel);
//
    /**
     * 批量删除设备型号
     *
     * @param modelIds 需要删除的设备型号主键集合
     * @return 结果
     */
    public int deleteEquModelByModelIds(Long[] modelIds);
//
//    /**
//     * 删除设备型号信息
//     *
//     * @param modelId 设备型号主键
//     * @return 结果
//     */
//    public int deleteEquModelByModelId(Long modelId);

    /**
     * 新增修改设备型号参数
     *
     * @param
     * @return 结果
     */
    public int updateEqumodelParamList(List<Map> ParamList);

    List<EquModel> selectEquInfoExportList(EquModelExportVo equInfoExportVo);


    String importData(List<EquModel> userList, Boolean isUpdateSupport) throws ServiceException;
}
